# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]
[Unreleased]: https://github.com/althonos/pyrodigal/compare/v0.2.1...HEAD


## [v0.2.1] - 2020-05-29
[v0.2.1]: https://github.com/althonos/pyrodigal/compare/v0.2.0...v0.2.1
### Fixed
- Memory issues causing PyPy to crash when using `Pyrodigal` in single mode.


## [v0.2.0] - 2020-05-28
[v0.2.0]: https://github.com/althonos/pyrodigal/compare/v0.1.1...v0.2.0
### Added
- Support for Prodigal's *single* mode.


## [v0.1.1] - 2020-04-30
[v0.1.1]: https://github.com/althonos/pyrodigal/compare/v0.1.0...v0.1.1
### Added
- Distribution of CPython wheels for ManyLinux2010 and OSX platforms.


## [v0.1.0] - 2020-04-27
[v0.1.0]: https://github.com/althonos/pyrodigal/compare/0a90bf9...v0.1.0

Initial release.
